ResolvedColorSpace

Enum ResolvedColorSpace 

pub enum ResolvedColorSpace {
    DeviceGray,
    DeviceRGB,
    DeviceCMYK,
    ICCBased {
        num_components: u32,
        alternate: Box<ResolvedColorSpace>,
    },
    Indexed {
        base: Box<ResolvedColorSpace>,
        hival: u32,
        lookup_table: Vec<u8>,
    },
    Separation {
        alternate: Box<ResolvedColorSpace>,
    },
    DeviceN {
        num_components: u32,
        alternate: Box<ResolvedColorSpace>,
    },
}
A resolved PDF color space with enough information to convert component values to a Color.

Variants



DeviceGray

DeviceGray (1 component).



DeviceRGB

DeviceRGB (3 components).



DeviceCMYK

DeviceCMYK (4 components).



ICCBased

ICCBased color space: stores the number of components and the alternate color space to use for conversion.

Fields

num_components: u32

Number of color components (1, 3, or 4).

alternate: Box<ResolvedColorSpace>

Alternate color space for fallback conversion.



Indexed

Indexed color space: a palette-based color space.

Fields

base: Box<ResolvedColorSpace>

Base color space that palette entries are specified in.

hival: u32

Maximum valid index value.

lookup_table: Vec<u8>

Color lookup table: (hival + 1) * num_base_components bytes.



Separation

Separation color space (single-component spot color). Best-effort: uses the alternate color space.

Fields

alternate: Box<ResolvedColorSpace>

Alternate color space (fallback).



DeviceN

DeviceN color space (multi-component named colors). Best-effort: uses the alternate color space.

Fields

num_components: u32

Number of color components.

alternate: Box<ResolvedColorSpace>

Alternate color space (fallback).

Implementations

Source

impl ResolvedColorSpace

pub fn num_components(&self) -> u32

Number of components expected for this color space.

pub fn resolve_color(&self, components: &[f32]) -> Color

Convert color components to a Color value using this color space.