PathEvent

Struct PathEvent 

pub struct PathEvent {
    pub segments: Vec<PathSegment>,
    pub paint_op: PaintOp,
    pub line_width: f64,
    pub stroking_color: Option<Color>,
    pub non_stroking_color: Option<Color>,
    pub ctm: [f64; 6],
    pub dash_pattern: Option<DashPattern>,
    pub fill_rule: Option<FillRule>,
}
Information about a painted path.

Produced by the interpreter when a path is stroked, filled, or both. Contains the path geometry, paint operation, and graphics state at the time of painting.

Fields

segments: Vec<PathSegment>

The path segments making up this path.

paint_op: PaintOp

The paint operation applied.

line_width: f64

Stroke line width.

stroking_color: Option<Color>

Stroking (outline) color.

non_stroking_color: Option<Color>

Non-stroking (fill) color.

ctm: [f64; 6]

Current transformation matrix at the time of painting.

dash_pattern: Option<DashPattern>

Dash pattern for stroked paths.

fill_rule: Option<FillRule>

Fill rule for filled paths.