pub fn show_string_cid(
text_state: &mut TextState,
string_bytes: &[u8],
get_width: &dyn Fn(u32) -> f64,
) -> Vec<RawChar>Expand description
Tj operator for CID fonts: show a string using 2-byte character codes.
For CID fonts (Type0/composite), each character code is formed from two consecutive bytes in big-endian order. If the byte string has an odd length, the last byte is treated as a single-byte code.