pub enum Operand {
Integer(i64),
Real(f64),
Name(String),
LiteralString(Vec<u8>),
HexString(Vec<u8>),
Array(Vec<Operand>),
Boolean(bool),
Null,
}Expand description
A PDF content stream operand value.
Variants
Integer(i64)
Integer number (e.g., 42, -7).
Real(f64)
Real (floating-point) number (e.g., 3.14, .5).
Name(String)
Name object (e.g., /F1, /DeviceRGB). Stored without the leading /.
LiteralString(Vec<u8>)
Literal string delimited by parentheses, stored as raw bytes.
HexString(Vec<u8>)
Hexadecimal string delimited by angle brackets, stored as decoded bytes.
Array(Vec<Operand>)
Array of operands (e.g., [1 2 3]).
Boolean(bool)
Boolean value (true or false).
Null
The null object.